function ind_keywds=sci_find_plus_minus(txt,keywd,preced)

// PURPOSE: in a text, find the indexes of the plus or minus
// operator, without retaining the ones correspodingd to
// exponents in numbers 
// ------------------------------------------------------------
// INPUT:
// * txt = a gauss statement component
// * ind_txt = the index of this gauss statement component
// * ind_length = a (1 x N) vector of integers, with 0 in the 
//   first place, then the position where the parts of the
//   statement end
// * keywds = a vector of keywords to search
// * ind_keywds =  a (4 x N) matrix, the first line indicates
//   the indexes of the keyword in a statement, the second
//   one the index of the component where the parenthesis has 
//   been found, the third line: the position of the operator
//   end, the fourth line: the precedence of the operator, as
//     indicated in the table of gauss manual (chapter 11-23
//     for gauss 10 version)
// * preced = the precedence of the operator
// ------------------------------------------------------------
// OUTPUT:
// * ind_keywds = the original matrix extended with the 
//   keywords found in the statement component
// ------------------------------------------------------------
// Copyright Eric Dubois 2010
// http://dubois.ensae.net/grocer.html

ind_keywds=strindex(txt,keywd)
for i=size(ind_keywds,2):-1:1
   ind_keywds_i=ind_keywds(i)
   txt_before=stripblanks(part(txt,1:ind_keywds_i-1))
   txt_before_last=part(txt_before,length(txt_before))
   if or(txt_before_last == ['e' 'd']) then
      txt_before=stripblanks(part(txt_before,1:length(txt_before)-1))
      txt_after=stripblanks(part(txt,ind_keywds_i+1:length(txt)))
      if isnum(part(txt_before,length(txt_before))) & isnum(part(txt_after,1)) then
      // the sign belongs to a numerical exponentation: remove it from the list
         ind_keywds(i)=[]
      end
   end
end 

if ~isempty(ind_keywds) then
   ind_keywds=[ind_keywds ; ...
              0*ind_keywds+length(keywd);...
              preced*ones(1,size(ind_keywds,2))]
end

endfunction
                        
